#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import logging

from neutronclient.neutron.v2_0 import CreateCommand
from neutronclient.neutron.v2_0 import DeleteCommand
from neutronclient.neutron.v2_0 import ListCommand
from neutronclient.neutron.v2_0 import ShowCommand
from neutronclient.neutron.v2_0 import UpdateCommand


class ListPolicy(ListCommand):
    """List Network Policy information that belong to a given tenant."""

    resource = 'policy'
    log = logging.getLogger(__name__ + '.ListPolicy')
    _formatters = {}
    list_columns = ['id', 'name']


class ShowPolicy(ShowCommand):
    """Show information of a given Policy."""

    resource = 'policy'
    log = logging.getLogger(__name__ + '.ShowPolicy')


class CreatePolicy(CreateCommand):
    """Create an Policy for a given tenant."""

    resource = 'policy'
    log = logging.getLogger(__name__ + '.CreatePolicy')

    def add_known_arguments(self, parser):
        parser.add_argument(
            '--method',
            default='fixed',
            help='Set Network Policy parameters')
        parser.add_argument(
            'name', metavar='name',
            help='Name of Policy to create')

    def args2body(self, parsed_args):
        body = {'policy': {
            'name': parsed_args.name, }, }
        if parsed_args.tenant_id:
            body['policy'].update({'tenant_id': parsed_args.tenant_id})
        return body


class DeletePolicy(DeleteCommand):
    """Delete a given Policy."""

    log = logging.getLogger(__name__ + '.DeletePolicy')
    resource = 'policy'


class UpdatePolicy(UpdateCommand):
    """Update Policy's information."""

    log = logging.getLogger(__name__ + '.UpdatePolicy')
    resource = 'policy'
