# Copyright (c) 2017 Mirantis Inc.
# All Rights Reserved
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
#

import sys

from neutronclient.neutron.v2_0 import policy
from neutronclient.tests.unit import test_cli20


class CLITestV20PolicyJSON(test_cli20.CLITestV20Base):

    non_admin_status_resources = ['policy']

    def setUp(self):
        super(CLITestV20PolicyJSON, self).setUp()
        self.res = 'policy'
        self.cmd_res = 'policy'
        self.ress = "policies"
        self.cmd_ress = 'policies'

    def test_create_policy_with_only_keyattributes(self):
        # Create policy abc.
        cmd = policy.CreatePolicy(test_cli20.MyApp(sys.stdout),
                                  None)
        myid = 'myid'
        name = 'abc'
        args = [name]
        position_names = ['name']
        position_values = [name]
        self._test_create_resource(self.res, cmd, name, myid, args,
                                   position_names, position_values,
                                   cmd_resource=self.cmd_res)

    def test_create_policy_with_unicode(self):
        # Create policy u'\u7f51\u7edc'.
        cmd = policy.CreatePolicy(test_cli20.MyApp(sys.stdout),
                                  None)
        myid = 'myid'
        name = u'\u7f51\u7edc'
        args = [name]
        position_names = ['name']
        position_values = [name]
        self._test_create_resource(self.res, cmd, name, myid, args,
                                   position_names, position_values,
                                   cmd_resource=self.cmd_res)

    def test_list_policies(self):
        # policy-list.
        cmd = policy.ListPolicy(test_cli20.MyApp(sys.stdout),
                                None)
        self._test_list_resources(self.ress, cmd, True,
                                  cmd_resources=self.cmd_ress)

    def test_show_policy_id(self):
        # policy-show test_id.
        cmd = policy.ShowPolicy(test_cli20.MyApp(sys.stdout),
                                None)
        args = ['--fields', 'id', self.test_id]
        self._test_show_resource(self.res, cmd, self.test_id, args,
                                 ['id'], cmd_resource=self.cmd_res)

    def test_show_policy_name(self):
        # policy-show name.
        # Skip this test since Contrail returns ALL policies if requested
        # to show just one policy by name.
        self.skipTest('Skip: contrail backend does not handle it correctly')
        cmd = policy.ShowPolicy(test_cli20.MyApp(sys.stdout),
                                None)
        args = ['--fields', 'id', '--fields', 'name', self.test_id]
        self._test_show_resource(self.res, cmd, self.test_id,
                                 args, ['id', 'name'],
                                 cmd_resource=self.cmd_res)

    def test_delete_policy(self):
        # policy-delete my-id.
        cmd = policy.DeletePolicy(test_cli20.MyApp(sys.stdout),
                                  None)
        my_id = 'myid1'
        args = [my_id]
        self._test_delete_resource(self.res, cmd, my_id, args,
                                   cmd_resource=self.cmd_res)
